@@ -1,5 +1,5 @@
 use safecoin_faucet::faucet::{request_airdrop_transaction, run_local_faucet};
-use solana_sdk::{
+use safecoin_sdk::{
     hash::Hash,
     message::Message,
     signature::{Keypair, Signer},
@@ -10,9 +10,9 @@ use solana_sdk::{
 #[test]
 fn test_local_faucet() {
     let keypair = Keypair::new();
-    let to = solana_sdk::pubkey::new_rand();
+    let to = safecoin_sdk::pubkey::new_rand();
     let lamports = 50;
-    let blockhash = Hash::new(&to.as_ref());
+    let blockhash = Hash::new(to.as_ref());
     let create_instruction = system_instruction::transfer(&keypair.pubkey(), &to, lamports);
     let message = Message::new(&[create_instruction], Some(&keypair.pubkey()));
     let expected_tx = Transaction::new(&[&keypair], message, blockhash);
